==> aws-cdk-lib-2.0.0-rc.6-sources.jar: software/amazon/awscdk/services/cloudfront/CachedMethods.java <==
package software.amazon.awscdk.services.cloudfront;

/**
 * (experimental) The HTTP methods that the Behavior will cache requests on.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-06-02T09:55:01.205Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_cloudfront.CachedMethods")
public class CachedMethods extends software.amazon.jsii.JsiiObject {

    protected CachedMethods(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CachedMethods(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        CACHE_GET_HEAD = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudfront.CachedMethods.class, "CACHE_GET_HEAD", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.CachedMethods.class));
        CACHE_GET_HEAD_OPTIONS = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudfront.CachedMethods.class, "CACHE_GET_HEAD_OPTIONS", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.CachedMethods.class));
    }

    /**
     * (experimental) HEAD and GET.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.cloudfront.CachedMethods CACHE_GET_HEAD;

    /**
     * (experimental) HEAD, GET, and OPTIONS.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public final static software.amazon.awscdk.services.cloudfront.CachedMethods CACHE_GET_HEAD_OPTIONS;

    /**
     * (experimental) HTTP methods supported.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getMethods() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "methods", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/services/cloudfront/CachedMethods.java <==
package software.amazon.awscdk.services.cloudfront;

/**
 * The HTTP methods that the Behavior will cache requests on.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.cloudfront.*;
 * CachedMethods cachedMethods = CachedMethods.CACHE_GET_HEAD;
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:07.956Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_cloudfront.CachedMethods")
public class CachedMethods extends software.amazon.jsii.JsiiObject {

    protected CachedMethods(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected CachedMethods(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        CACHE_GET_HEAD = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudfront.CachedMethods.class, "CACHE_GET_HEAD", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.CachedMethods.class));
        CACHE_GET_HEAD_OPTIONS = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.cloudfront.CachedMethods.class, "CACHE_GET_HEAD_OPTIONS", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cloudfront.CachedMethods.class));
    }

    /**
     * HEAD and GET.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.cloudfront.CachedMethods CACHE_GET_HEAD;

    /**
     * HEAD, GET, and OPTIONS.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.cloudfront.CachedMethods CACHE_GET_HEAD_OPTIONS;

    /**
     * HTTP methods supported.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getMethods() {
        return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "methods", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
    }
}
